### * <HEADER>
###
attach(NULL, name = "CheckExEnv")
assign("nameEx", 
       local({
	   s <- "__{must remake R-ex/*.R}__"
           function(new) {
               if(!missing(new)) s <<- new else s
           }
       }),
       pos = "CheckExEnv")
## Add some hooks to label plot pages for base and grid graphics
assign("base_plot_hook",
       function() {
           pp <- par(c("mfg","mfcol","oma","mar"))
           if(all(pp$mfg[1:2] == c(1, pp$mfcol[2]))) {
               outer <- (oma4 <- pp$oma[4]) > 0; mar4 <- pp$mar[4]
               mtext(sprintf("help(\"%s\")", nameEx()), side = 4,
                     line = if(outer)max(1, oma4 - 1) else min(1, mar4 - 1),
               outer = outer, adj = 1, cex = .8, col = "orchid", las=3)
           }
       },
       pos = "CheckExEnv")
assign("grid_plot_hook",
       function() {
           grid::pushViewport(grid::viewport(width=grid::unit(1, "npc") - 
                              grid::unit(1, "lines"), x=0, just="left"))
           grid::grid.text(sprintf("help(\"%s\")", nameEx()),
                           x=grid::unit(1, "npc") + grid::unit(0.5, "lines"),
                           y=grid::unit(0.8, "npc"), rot=90,
                           gp=grid::gpar(col="orchid"))
       },
       pos = "CheckExEnv")
setHook("plot.new",     get("base_plot_hook", pos = "CheckExEnv"))
setHook("persp",        get("base_plot_hook", pos = "CheckExEnv"))
setHook("grid.newpage", get("grid_plot_hook", pos = "CheckExEnv"))
assign("cleanEx",
       function(env = .GlobalEnv) {
	   rm(list = ls(envir = env, all.names = TRUE), envir = env)
           RNGkind("default", "default")
	   set.seed(1)
   	   options(warn = 1)
	   .CheckExEnv <- as.environment("CheckExEnv")
	   delayedAssign("T", stop("T used instead of TRUE"),
		  assign.env = .CheckExEnv)
	   delayedAssign("F", stop("F used instead of FALSE"),
		  assign.env = .CheckExEnv)
	   sch <- search()
	   newitems <- sch[! sch %in% .oldSearch]
	   for(item in rev(newitems))
               eval(substitute(detach(item), list(item=item)))
	   missitems <- .oldSearch[! .oldSearch %in% sch]
	   if(length(missitems))
	       warning("items ", paste(missitems, collapse=", "),
		       " have been removed from the search path")
       },
       pos = "CheckExEnv")
assign("ptime", proc.time(), pos = "CheckExEnv")
## at least one package changes these via ps.options(), so do this
## before loading the package.
## Use postscript as incomplete files may be viewable, unlike PDF.
## Choose a size that is close to on-screen devices, fix paper
ps.options(width = 7, height = 7, paper = "a4", reset = TRUE)
grDevices::postscript("edci-Ex.ps")
		      
assign("par.postscript", graphics::par(no.readonly = TRUE), pos = "CheckExEnv")
options(contrasts = c(unordered = "contr.treatment", ordered = "contr.poly"), pager="console")
options(warn = 1)    
library('edci')

assign(".oldSearch", search(), pos = 'CheckExEnv')
assign(".oldNS", loadedNamespaces(), pos = 'CheckExEnv')
cleanEx(); nameEx("circMclust")
### * circMclust

flush(stderr()); flush(stdout())

### Name: circMclust
### Title: Circular Clustering
### Aliases: circMclust plot.circMclust print.circMclust
### Keywords: cluster regression robust

### ** Examples

  z <- (1:100 * pi)/50
  x <- c(sin(z) * 10 + 20,sin(z) * 30 + 80)+rnorm(200,0,2)
  y <- c(cos(z) * 10 + 20,cos(z) * 30 + 80)+rnorm(200,0,2)

  circ <- circMclust(x,y,5,method="prob",prec=1,nsc=20,minsd=10,maxsd=40)
  bestMclust(circ,2)
  plot(bestMclust(circ,2),x,y)



cleanEx(); nameEx("edgecluster")
### * edgecluster

flush(stderr()); flush(stdout())

### Name: edgecluster
### Title: Edge detection in noisy images
### Aliases: edgecluster
### Keywords: robust multivariate nonparametric

### ** Examples

  y <- matrix(rep(0,60*60),nrow=60)
  y[21:40,21:40]<-1
  y <- y + matrix(rnorm(60*60,0,0.2),nrow=60)
  image(y,col=gray(seq(0,1,1/255)))

  ec <- edgecluster(y,0.05,0.05,0.7,
                    estimator="M_median",kernel="gauss")
  plot(bestMclust(ec[[1]],4),ec[[2]],xlim=c(0,1),ylim=c(0,1))



cleanEx(); nameEx("edgepoints")
### * edgepoints

flush(stderr()); flush(stdout())

### Name: edgepoints
### Title: Edge detection in noisy images
### Aliases: edgepoints
### Keywords: robust multivariate nonparametric

### ** Examples

  y <- matrix(rep(0,60*60),nrow=60)
  y[21:40,21:40]<-1
  y <- y + matrix(rnorm(60*60,0,0.2),nrow=60)
  image(y,col=gray(seq(0,1,1/255)))

  ye <- edgepoints(y,0.05,0.05,estimator="M_median",kernel="gauss")
  image(ye[[1]]>0.7,col=gray(c(1,0)))



cleanEx(); nameEx("oregMclust")
### * oregMclust

flush(stderr()); flush(stdout())

### Name: oregMclust
### Title: Orthogonal Regression Clustering
### Aliases: oregMclust regparm plot.oregMclust print.oregMclust
### Keywords: cluster regression robust

### ** Examples

  x <- c(rnorm(100,0,3),rnorm(100,5,3))
  y <- c(-2*x[1:100]-5,0.5*x[101:200]+30)/2
  x <- x + rnorm(200,0,0.5)
  y <- y + rnorm(200,0,0.5)

  reg <- oregMclust(x,y,1,method="prob")
  reg <- projMclust(reg,x,y)
  reg
  plot(bestMclust(reg,2,crit="proj"),x,y)



### * <FOOTER>
###
cat("Time elapsed: ", proc.time() - get("ptime", pos = 'CheckExEnv'),"\n")
grDevices::dev.off()
###
### Local variables: ***
### mode: outline-minor ***
### outline-regexp: "\\(> \\)?### [*]+" ***
### End: ***
quit('no')
